CsiConfig

Struct CsiConfig 

pub struct CsiConfig {
    pub lltf_en: bool,
    pub htltf_en: bool,
    pub stbc_htltf2_en: bool,
    pub ltf_merge_en: bool,
    pub channel_filter_en: bool,
    pub manu_scale: bool,
    pub shift: u8,
    pub dump_ack_en: bool,
}
Available on crate features csi and unstable only.
Channel state information (CSI) configuration.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Fields

lltf_en: bool

Enable to receive legacy long training field(lltf) data.

htltf_en: bool

Enable to receive HT long training field(htltf) data.

stbc_htltf2_en: bool

Enable to receive space time block code HT long training field(stbc-htltf2) data.

ltf_merge_en: bool

Enable to generate htlft data by averaging lltf and ht_ltf data when receiving HT packet. Otherwise, use ht_ltf data directly.

channel_filter_en: bool

Enable to turn on channel filter to smooth adjacent sub-carrier. Disable it to keep independence of adjacent sub-carrier.

manu_scale: bool

Manually scale the CSI data by left shifting or automatically scale the CSI data. If set true, please set the shift bits. false: automatically. true: manually.

shift: u8

Manually left shift bits of the scale of the CSI data. The range of the left shift bits is 0~15.

dump_ack_en: bool

Enable to dump 802.11 ACK frame.